# qwertyui
Some common Python functions and algorithms

# `backups`
Generic backup handling. Contains code for periodic backup removal with custom
rules regarding backup dates.

# `minio`
Some wrappers around the Minio Python client.

# `odoo`
Tools for interacting with Odoo.
